Enum hyperscan::expression::info::MatchAtEndBehavior
source · #[repr(i8)]pub enum MatchAtEndBehavior {
WillNeverMatchAtEOD = 0,
MayMatchAtEOD = 1,
WillOnlyMatchAtEOD = 2,
}Available on crate feature
compiler only.Expand description
Whether this expression can produce matches at end of data (EOD).
In streaming mode, EOD matches are raised during
Scratch::flush_eod_sync() or
Scratch::flush_eod(), since it is
only when flush_eod() is called that the EOD location is
known.
Note: trailing \b word boundary assertions may also result in EOD
matches as end-of-data can act as a word boundary.
Variants
WillNeverMatchAtEOD = 0
Pattern will never match at EOD.
MayMatchAtEOD = 1
Pattern may match at EOD.
WillOnlyMatchAtEOD = 2
Pattern will only match at EOD.
Implementations
sourceimpl MatchAtEndBehavior
impl MatchAtEndBehavior
pub fn from_native(matches_at_eod: c_char, matches_only_at_eod: c_char) -> Self