Enum hyperscan::expression::info::UnorderedMatchBehavior
source · #[repr(i8)]pub enum UnorderedMatchBehavior {
OnlyOrdered = 0,
AllowsUnordered = 1,
}Available on crate feature
compiler only.Expand description
Whether the expression can produce matches that are not returned in order, such as those produced by assertions.
Variants
OnlyOrdered = 0
Disallows matches that are not returned in order.
AllowsUnordered = 1
Allows matches that are not returned in order.
Implementations
sourceimpl UnorderedMatchBehavior
impl UnorderedMatchBehavior
pub const fn from_native(x: c_char) -> Self