Struct hyperscan::expression::info::ExprWidth
source · #[repr(transparent)]pub struct ExprWidth(pub usize);Available on crate feature
compiler only.Expand description
The upper or lower bound for the length of any matches returned by a pattern.
Tuple Fields
0: usizeTrait Implementations
sourceimpl Ord for ExprWidth
impl Ord for ExprWidth
sourceimpl PartialEq for ExprWidth
impl PartialEq for ExprWidth
sourceimpl PartialOrd for ExprWidth
impl PartialOrd for ExprWidth
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for ExprWidth
impl Eq for ExprWidth
impl StructuralEq for ExprWidth
impl StructuralPartialEq for ExprWidth