Struct hyperscan::expression::ExprId
source · #[repr(transparent)]pub struct ExprId(pub c_uint);Available on crate feature
compiler only.Expand description
The ID number to associate with a pattern match in an expression set.
When provided to an expression set, this value is converted into an
ExpressionIndex in a
Match,
VectoredMatch, or
ChimeraMatch upon matching the
given pattern.
This ID is used in ExpressionSet::with_ids(),
LiteralSet::with_ids(), and
ChimeraExpressionSet::with_ids().
Tuple Fields
0: c_uintTrait Implementations
sourceimpl Ord for ExprId
impl Ord for ExprId
sourceimpl PartialEq for ExprId
impl PartialEq for ExprId
sourceimpl PartialOrd for ExprId
impl PartialOrd for ExprId
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for ExprId
impl Eq for ExprId
impl StructuralEq for ExprId
impl StructuralPartialEq for ExprId