pub struct Mode(/* private fields */);compiler only.Expand description
Compiler mode flags that affect the database as a whole.
No Default impl is provided to enforce that at least one of
STREAM, BLOCK, or
VECTORED is supplied, to select between the generation
of a streaming, block or vectored database. In addition, other flags may be
supplied to enable or configure specific features such as stream state size.
Implementations
sourceimpl Mode
impl Mode
Basic database types.
For now, each database can only be one type (this is checked by hyperscan upon database creation).
sourceimpl Mode
impl Mode
Stream state precision modes.
These flags are currently only processed when Self::STREAM is requested.
sourcepub const SOM_HORIZON_LARGE: Self = _
pub const SOM_HORIZON_LARGE: Self = _
Use full precision to track start of match offsets in stream state.
This mode will use the most stream state per pattern, but will always return an accurate start of match offset regardless of how far back in the past it was found.
One of the SOM_HORIZON_* modes must be selected to use the
Flags::SOM_LEFTMOST expression flag.
sourcepub const SOM_HORIZON_MEDIUM: Self = _
pub const SOM_HORIZON_MEDIUM: Self = _
Use medium precision to track start of match offsets in stream state.
This mode will use less stream state than
Self::SOM_HORIZON_LARGE and will limit start of
match accuracy to offsets within 2^32 bytes of the end of match offset
reported.
One of the SOM_HORIZON_* modes must be selected to use the
Flags::SOM_LEFTMOST expression flag.
sourcepub const SOM_HORIZON_SMALL: Self = _
pub const SOM_HORIZON_SMALL: Self = _
Use limited precision to track start of match offsets in stream state.
This mode will use less stream state than
Self::SOM_HORIZON_LARGE and will limit start of
match accuracy to offsets within 2^16 bytes of the end of match offset
reported.
One of the SOM_HORIZON_* modes must be selected to use the
Flags::SOM_LEFTMOST expression flag.